with Universal_Types;
use Universal_Types;
package body Display is
    function Fill (S : String; Width : Natural) return String is
    begin
	if S'Length <= Width then
	    return String'(1 .. Width - S'Length => ' ') & S;
	else
	    return S (S'First .. S'First + Width - 1);
	end if;
    end Fill;

    function Filled_Image (N : Numeric; Width : Natural) return String is
	N_Image : constant String := Numeric'Image (N);
    begin
	return Fill (S => N_Image, Width => Width);
    end Filled_Image;


    procedure Put (C : Coordinates_2D.Object; Char : Character) is
    begin
	Screen_Io.Position_Cursor (C => C);
	Screen_Io.Put (Char => Char);
    end Put;

    procedure Put (L : Screen_Io.Line; C : Screen_Io.Column; Str : String) is
    begin
	Screen_Io.Position_Cursor (L => L, C => C);
	Screen_Io.Put (S => Str);
    end Put;

    procedure Put_Summary_Title (L : Screen_Io.Line; C : Screen_Io.Column) is

	Titles : constant String := 
	   "Planet X-Velocity Y-Velocity X-Coord. Y-Coord.";
    begin
	Put (L => L, C => C, Str => Titles);
    end Put_Summary_Title;

    procedure Put_Summary_Info (L : Screen_Io.Line; 
				C : Screen_Io.Column; 
				Planet : Character; 
				Coordinates : Coordinates_2D.Object; 
				Velocity : Velocity_2D.Object) is
	function Build_Orbit_String (Orbit_Char : Character; 
				     C : Coordinates_2D.Object; 
				     V : Velocity_2D.Object) return String is
	    Xv : Velocity_2D.Offset := Velocity_2D.X_Offset (V);
	    Yv : Velocity_2D.Offset := Velocity_2D.Y_Offset (V);
	    X : Coordinates_2D.Position := Coordinates_2D.X_Position (C);
	    Y : Coordinates_2D.Position := Coordinates_2D.Y_Position (C);
	begin
	    return Orbit_Char & "  " &  
		      Filled_Image (N => Xv, Width => 3) & 
		      Filled_Image (N => Yv, Width => 3) & 
		      Filled_Image (N => X, Width => 5) & 
		      Filled_Image (N => Y, Width => 5);
	end Build_Orbit_String;
    begin
	Screen_Io.Position_Cursor (L => L, C => C);
	Screen_Io.Put (S => Build_Orbit_String (Planet, Coordinates, Velocity));
    end Put_Summary_Info;

end Display;
