with Planet;
with Screen_Io;
with Display;
with Orbit_Decorations;
with Coordinates_2D;
with Velocity_2D;
with Universal_Constants;
with Universal_Types;
use Universal_Types;

procedure Planetary_Motion is

    Number_Of_Planets : constant := 2;

    Standard_Column : constant Screen_Io.Column := 0;
    Title_Line : constant Screen_Io.Screen_Coordinate := 
       Screen_Io.Max_Physical_Height - Number_Of_Planets;
    Planet_1_Line : constant Screen_Io.Screen_Coordinate := 
       Screen_Io.Max_Physical_Height - Number_Of_Planets + 1;
    Planet_2_Line : constant Screen_Io.Screen_Coordinate := 
       Screen_Io.Max_Physical_Height - Number_Of_Planets + 2;

    Planet_1_X : constant Coordinates_2D.Position := 
       0 * Universal_Constants.Scale_Factor;
    Planet_1_Y : constant Coordinates_2D.Position := 
       105 * Universal_Constants.Scale_Factor;
    Planet_1_Coordinates : Coordinates_2D.Object := 
       Coordinates_2D.Make (X_Position => Planet_1_X, Y_Position => Planet_1_Y);
    Planet_1_Xv : constant Velocity_2D.Offset := 
       -9 * Universal_Constants.Scale_Factor;
    Planet_1_Yv : constant Velocity_2D.Offset := 
       3 * Universal_Constants.Scale_Factor;
    Planet_1_Velocity : Velocity_2D.Object := 
       Velocity_2D.Make (X_Offset => Planet_1_Xv, 
			 Y_Offset => Planet_1_Yv, 
			 Delta_Time => Universal_Constants.Delta_Time);
    package Planet_1 is new Planet (Initial_Coordinates => Planet_1_Coordinates, 
				    Initial_Velocity => Planet_1_Velocity, 
				    Decoration => Orbit_Decorations.Planet_1);

    Planet_2_X : constant Coordinates_2D.Position := 
       -100 * Universal_Constants.Scale_Factor;
    Planet_2_Y : constant Coordinates_2D.Position := 
       0 * Universal_Constants.Scale_Factor;
    Planet_2_Coordinates : Coordinates_2D.Object := 
       Coordinates_2D.Make (X_Position => Planet_2_X, Y_Position => Planet_2_Y);
    Planet_2_Xv : constant Velocity_2D.Offset := 
       -2 * Universal_Constants.Scale_Factor;
    Planet_2_Yv : constant Velocity_2D.Offset := 
       9 * Universal_Constants.Scale_Factor;
    Planet_2_Velocity : Velocity_2D.Object := 
       Velocity_2D.Make (X_Offset => Planet_2_Xv, 
			 Y_Offset => Planet_2_Yv, 
			 Delta_Time => Universal_Constants.Delta_Time);
    package Planet_2 is new Planet (Initial_Coordinates => Planet_2_Coordinates, 
				    Initial_Velocity => Planet_2_Velocity, 
				    Decoration => Orbit_Decorations.Planet_2);


begin
    Display.Put_Summary_Title (L => Title_Line, C => Standard_Column);
    Display.Put (C => Coordinates_2D.Center, Char => Orbit_Decorations.Sun);

    Planet_1.Make;
    Planet_2.Make;

    loop
	Planet_1.Display_Planet;
	Planet_2.Display_Planet;

	Display.Put_Summary_Info (L => Planet_1_Line, 
				  C => Standard_Column, 
				  Planet => Orbit_Decorations.Planet_1, 
				  Coordinates => Planet_1.Current_Coordinates, 
				  Velocity => Planet_1.Current_Velocity);
	Display.Put_Summary_Info (L => Planet_2_Line, 
				  C => Standard_Column, 
				  Planet => Orbit_Decorations.Planet_2, 
				  Coordinates => Planet_2.Current_Coordinates, 
				  Velocity => Planet_2.Current_Velocity);
	Planet_1.Update_Orbit;
	Planet_2.Update_Orbit;

	delay 0.01;

    end loop;

end Planetary_Motion;
