-- 
-- File Name: screen_io.1.ada
-- 

with Universal_Types;
use Universal_Types;
with Coordinates_2D;
package Screen_Io is

    subtype Screen_Coordinate is Numeric range 0 .. Numeric'Last;
    --upper left coordinate is 0,0

    subtype Line is Screen_Coordinate;
    subtype Column is Screen_Coordinate;

    function Max_Physical_Width return Column;
    function Max_Physical_Height return Line;

    procedure Initialize;

    procedure Finalize;

    procedure Clear_Screen;

    procedure Position_Cursor (C : Coordinates_2D.Object);
    -- this function positions the cursor based on universal coordinates
    -- which are centered around (0,0)

    procedure Position_Cursor (L : Line; C : Column);
    -- position the cursor at some absolute screen coordinates

    procedure Put (Char : Character);

    procedure Put (S : String);

    procedure Flush;

    procedure Get_No_Wait (Valid_Char : out Boolean; Char : out Character);

    Out_Of_Bounds : exception;
    -- this exception raised on attempts to position cursor out of the
    -- physical bounds of the screen

end Screen_Io;
