with Text_Io;
with Universal_Constants;
package body Screen_Io is

    Screen_Height : constant Screen_Coordinate := 24;
    Screen_Width : constant Screen_Coordinate := 80;
    Char_Height : constant Numeric := 12;
    Char_Width : constant Numeric := 9;
    -- these are constant now but should really be obtain from the unix 
    -- environment or X but ... 

    X_Center_Offset : constant Screen_Coordinate := (Screen_Width - 1) / 2 + 1;
    Y_Center_Offset : constant Screen_Coordinate := (Screen_Height - 1) / 2 + 1;

    Position_Cursor_String : constant String := 
       (Ascii.Esc, '[', '0', '0', ';', '0', '0', 'H');

    Clear_Screen_String : constant String := (Ascii.Esc, '[', '2', 'J');

    function Max_Physical_Width return Column is
    begin
	return Screen_Width;
    end Max_Physical_Width;

    function Max_Physical_Height return Line is
    begin
	return Screen_Height;
    end Max_Physical_Height;

    procedure Initialize is
    begin
	Clear_Screen;
    end Initialize;

    procedure Finalize is
    begin
	null;
    end Finalize;

    procedure Clear_Screen is
    begin
	Put (S => Clear_Screen_String);
    end Clear_Screen;

    procedure Put (Char : Character) is
    begin
	Text_Io.Put (Item => Char);
    end Put;

    procedure Put (S : String) is
    begin
	Text_Io.Put (Item => S);
    end Put;

    procedure Translate_To_Screen_Coordinates 
		 (C : Coordinates_2D.Object; 
		  Line : out Screen_Coordinate; 
		  Column : out Screen_Coordinate) is
	X : Coordinates_2D.Position := Coordinates_2D.X_Position (C);
	Y : Coordinates_2D.Position := Coordinates_2D.Y_Position (C);


    begin
	Column := X / Universal_Constants.Scale_Factor / Char_Width + 
		     X_Center_Offset;
	Line := -Y / Universal_Constants.Scale_Factor / Char_Height + 
		   Y_Center_Offset;
    exception
	when Constraint_Error =>
	    raise Out_Of_Bounds;
    end Translate_To_Screen_Coordinates;

    procedure Position_Cursor (C : Coordinates_2D.Object) is
	Line : Screen_Coordinate;
	Column : Screen_Coordinate;
    begin
	Translate_To_Screen_Coordinates 
	   (C => C, Line => Line, Column => Column);
	Position_Cursor (L => Line, C => Column);
    end Position_Cursor;

    procedure Position_Cursor (L : Line; C : Column) is
	Zero : constant Numeric := Character'Pos ('0');
	Cursor_String : String (Position_Cursor_String'Range) := 
	   Position_Cursor_String;
	First : constant Positive := Cursor_String'First;
    begin
	if L <= Screen_Height and then C <= Screen_Width then
	    Cursor_String (First + 2) := Character'Val (Zero + L / 10);
	    Cursor_String (First + 3) := Character'Val (Zero + L mod 10);
	    Cursor_String (First + 5) := Character'Val (Zero + C / 10);
	    Cursor_String (First + 6) := Character'Val (Zero + C mod 10);
	    Text_Io.Put (Cursor_String);
	else
	    raise Out_Of_Bounds;
	end if;
    end Position_Cursor;

    procedure Get_No_Wait (Valid_Char : out Boolean; Char : out Character) is
    begin
	Valid_Char := False;
	Char := Ascii.Nul;
	-- this need to be written to actually a character but it is stubed
	-- out for now.
    end Get_No_Wait;

    procedure Flush is
    begin
	null;
    end Flush;

end Screen_Io;
